..
   Copyright (c) 2019 - 2020 TomTom N.V. (https://tomtom.com)
   
   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
   
       http://www.apache.org/licenses/LICENSE-2.0
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

..
   Hopic documentation master file, created by
   sphinx-quickstart on Mon Jan 28 13:57:37 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Hopic
=====

.. include:: ../../README.rst

Contents
========

.. toctree::
   :maxdepth: 2

   usage
   intro
   config
   hotfix
   CONTRIBUTING
   changes

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

